@@ -81,11 +81,15 @@ strect <- function (str, pattern) regmatches(str, regexpr(pattern, str))
 err_handle <- function(x, store, key) {
   if (x$status_code > 201) {
     tt <- if (store$store == "disk") x$content else x$parse("UTF-8")
-    html <- read_html(tt)
-    mssg <- xml_text(xml_find_all(html, '//body//p[text()[contains(., "error")]]')) %||% ""
-    mssg <- sub("Message\\s", "", mssg)
-    if (nchar(mssg) == 0) {
-      mssg <- strect(xml_text(xml_find_first(html, '//body')), "Query error.+")
+    html <- tryCatch(read_html(tt), error = function(e) e)
+    if (inherits(html, "error")) {
+      mssg <- tt
+    } else {
+      mssg <- xml_text(xml_find_all(html, '//body//p[text()[contains(., "error")]]')) %||% ""
+      mssg <- sub("Message\\s", "", mssg)
+      if (nchar(mssg) == 0) {
+        mssg <- strect(xml_text(xml_find_first(html, '//body')), "Query error.+")
+      }
     }
     if (store$store != "memory") unlink(file.path(store$path, key))
     stop(paste0(mssg, collapse = "\n\n"), call. = FALSE)
